
Gabbi gets better because of the contributions from the people who use
it. These contributions come in many forms:

* Joining the #gabbi channel on Freenode IRC at freenode.net and
  having a chat.
* Improvements to make the documentation more complete, more correct
  and typo free.
* Reporting and reviewing bugs in the
  [issues](https://github.com/cdent/gabbi/issues)
* Providing [pull requests](https://github.com/cdent/gabbi/pulls)
  containing fixes and new features.

If you have an idea for a new feature it is best to review the
[Ideas](https://github.com/cdent/gabbi/wiki/Ideas) wiki page and the
existing issues and pull requests to see if there is existing work you
can contribute to. It's also worthwhile to ask around in IRC.

In general the default stance with gabbi is to avoid adding new features
if we can come up with some way to use the existing features to solve
the requirements of your tests. This helps to keep the test format
as clean and readable as possible.

If you reach an impasse, create an issue and provide as much info as you
can about your situation and together we can try to figure it out.
